@@ -50,7 +50,7 @@ class AthenaClient:
             r = requests.post(SERVICE_URL + API_GET_ATHENA_DATABASES, data=payload, headers=HEADERS)
             response = r.json()
             if result_as_df:
-                response_as_df = pd.DataFrame.from_dict(response, orient="index")
+                response_as_df = pd.DataFrame.from_dict(response)
                 return response_as_df
             else:
                 return response
@@ -70,7 +70,7 @@ class AthenaClient:
             r = requests.post(SERVICE_URL + API_GET_ATHENA_TABLES, data=payload, headers=HEADERS)
             response = r.json()
             if result_as_df:
-                response_as_df = pd.DataFrame.from_dict(response, orient="index")
+                response_as_df = pd.DataFrame.from_dict(response)
                 return response_as_df
             else:
                 return response
@@ -91,7 +91,7 @@ class AthenaClient:
             r = requests.post(SERVICE_URL + API_QUERY_ATHENA_TABLE, data=payload, headers=HEADERS)
             response = r.json()
             if result_as_df:
-                response_as_df = pd.DataFrame.from_dict(response, orient="index")
+                response_as_df = pd.DataFrame.from_dict(response)
                 return response_as_df
             else:
                 return response
@@ -113,7 +113,7 @@ class AthenaClient:
             r = requests.post(SERVICE_URL + API_RUN_QUERY_ON_ATHENA, data=payload, headers=HEADERS)
             response = r.json()
             if result_as_df:
-                response_as_df = pd.DataFrame.from_dict(response, orient="index")
+                response_as_df = pd.DataFrame.from_dict(response)
                 return response_as_df
             else:
                 return response
